@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[1]:
+# In[2]:
 
 
 try:
-    from IPython.display import display, Javascript
-    display(Javascript('Jupyter.notebook.kernel.execute("nb_name = \'" + Jupyter.notebook.notebook_name + "\'");'))
+    if get_ipython().__class__.__name__ == 'ZMQInteractiveShell':
+        from IPython.display import display, Javascript
+        display(Javascript('Jupyter.notebook.kernel.execute("nb_name = \'" + Jupyter.notebook.notebook_name + "\'");'));
 except:
         pass
 
@@ -14,8 +15,7 @@ except:
 # In[3]:
 
 
-version = '0.45'
-def is_testing(): return False
+version = '0.46'
 
 import re
 import tempfile
@@ -32,7 +32,7 @@ import stat
 
 # # Helper Functions
 
-# In[5]:
+# In[4]:
 
 
 def is_testing():
@@ -42,7 +42,7 @@ def is_testing():
         return False
 
 
-# In[6]:
+# In[5]:
 
 
 def isnotebook():
@@ -60,7 +60,7 @@ def isnotebook():
 #         pass
 #     return False
 
-# In[7]:
+# In[6]:
 
 
 def testPrint(*args):
@@ -70,7 +70,7 @@ def testPrint(*args):
 
 # # Requiremtns
 
-# In[8]:
+# In[7]:
 
 
 requirements = []
@@ -96,14 +96,14 @@ from IPython.core.display import display, HTML
 
 # # Lists
 
-# In[9]:
+# In[8]:
 
 
 def listsGetPairsFromTwoLists(list1, list2):
     return list(zip(list1, list2))
 
 
-# In[10]:
+# In[9]:
 
 
 if is_testing():
@@ -113,14 +113,14 @@ if is_testing():
     print(listsGetPairsFromTwoLists(listAbcd, list1234))
 
 
-# In[11]:
+# In[10]:
 
 
 def listSequentialOverlappingPairs(l):
     return list(zip(l[:-1], l[1:]))
 
 
-# In[12]:
+# In[11]:
 
 
 if is_testing():
@@ -130,7 +130,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[13]:
+# In[12]:
 
 
 regex_cache = {}
@@ -140,39 +140,53 @@ def sListFilter(l, re_include=".*", re_exclude='^\b$'):
     return [e for e in l if regex_cache[re_include].search(e) and not regex_cache[re_exclude].search(e)]
 
 
-# In[14]:
+# In[13]:
 
 
 if is_testing():
     sListFilter(['good x', 'other good x', 'without the letter before y'])
 
 
-# In[15]:
+# In[14]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[16]:
+# In[15]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[17]:
+# In[16]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# # Text files
+# In[17]:
+
+
+def lCsv(l):
+    return ", ".join([str(e) for e in l])
+
 
 # In[18]:
 
 
+if is_testing():
+    print(lCsv(['a', 'b', 1, 3.14]))
+
+
+# # Text files
+
+# In[19]:
+
+
 def txtread(path):
     if 'http://' in path or 'https://' in path:
         return urlopen(path).read().decode()
@@ -186,7 +200,7 @@ def txtwrite(path, txt):
         return f.write(txt)
 
 
-# In[19]:
+# In[20]:
 
 
 if is_testing():
@@ -195,7 +209,7 @@ if is_testing():
 
 # # List of Strings
 
-# In[20]:
+# In[21]:
 
 
 regex_cache = {}
@@ -207,35 +221,35 @@ def sListFilter(listOfStrings, re_include=".*", re_exclude='^\b$'):
 
 # ### Examples
 
-# In[21]:
+# In[22]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y']))
 
 
-# In[22]:
+# In[23]:
 
 
 if is_testing():
     print(sListFilter(['good x', 'other good x', 'without the letter before y'], re_include='x'))
 
 
-# In[23]:
+# In[24]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+'))
 
 
-# In[24]:
+# In[25]:
 
 
 if is_testing():
     print(sListFilter(['not enough x', 'enough xx', 'enough xx and also z'], re_include='xx+', re_exclude='z'))
 
 
-# In[25]:
+# In[26]:
 
 
 if is_testing():
@@ -244,7 +258,7 @@ if is_testing():
 
 # # Images
 
-# In[26]:
+# In[27]:
 
 
 def imread(path):
@@ -274,7 +288,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255):
     return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
 
 
-# In[27]:
+# In[28]:
 
 
 def imshow(array, scale=1):
@@ -289,7 +303,7 @@ def imshow(array, scale=1):
         cv2.waitKey()
 
 
-# In[28]:
+# In[29]:
 
 
 if is_testing():
@@ -297,14 +311,14 @@ if is_testing():
     imshow(img)
 
 
-# In[29]:
+# In[30]:
 
 
 if is_testing():
     imshow('http://via.placeholder.com/70.png')
 
 
-# In[30]:
+# In[31]:
 
 
 def imscaleNN(img, s):
@@ -314,7 +328,7 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[31]:
+# In[32]:
 
 
 if is_testing():
@@ -333,33 +347,33 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[32]:
+# In[33]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[33]:
+# In[34]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[34]:
+# In[35]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[35]:
+# In[36]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[36]:
+# In[37]:
 
 
 def imAddNoiseGauss(img, std):
@@ -371,7 +385,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imread('http://via.placeholder.com/150.png'), 10))
 
 
-# In[37]:
+# In[38]:
 
 
 def imJpgDegradation(img, quality):
@@ -384,7 +398,7 @@ def imJpgDegradation(img, quality):
 if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[38]:
+# In[39]:
 
 
 def imCropCenter(img, size):
@@ -399,35 +413,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[39]:
+# In[40]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[40]:
+# In[41]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[41]:
+# In[42]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[42]:
+# In[43]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[43]:
+# In[44]:
 
 
 def imGallery(imgs, pad=0):
@@ -458,7 +472,7 @@ def imGallery(imgs, pad=0):
     return out
 
 
-# In[44]:
+# In[45]:
 
 
 if is_testing():
@@ -466,49 +480,49 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[45]:
+# In[46]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:1]))
 
 
-# In[46]:
+# In[47]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2]))
 
 
-# In[47]:
+# In[48]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2], pad=1))
 
 
-# In[48]:
+# In[49]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:5], pad=1))
 
 
-# In[49]:
+# In[50]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:9], pad=1))
 
 
-# In[50]:
+# In[51]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1))
 
 
-# In[51]:
+# In[52]:
 
 
 if is_testing():
@@ -518,14 +532,14 @@ if is_testing():
 
 # # Files
 
-# In[52]:
+# In[53]:
 
 
 def fiFindByWildcard(wildcard):
     return natsort.natsorted(glob.glob(wildcard, recursive=True))
 
 
-# In[53]:
+# In[54]:
 
 
 if is_testing():
@@ -554,7 +568,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[54]:
+# In[55]:
 
 
 def fiRemove(path):
@@ -582,7 +596,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[55]:
+# In[56]:
 
 
 if is_testing():
@@ -616,7 +630,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[56]:
+# In[57]:
 
 
 def jnImageRenderingPixelated():
@@ -628,7 +642,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[57]:
+# In[58]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -641,7 +655,7 @@ if is_testing():
     
 
 
-# In[58]:
+# In[59]:
 
 
 def jnImgToHtmlB64(img):
@@ -665,7 +679,7 @@ def jnImageRow(imgs, names=None, width=100):
     display(HTML(html))
 
 
-# In[59]:
+# In[60]:
 
 
 if is_testing():
@@ -673,7 +687,7 @@ if is_testing():
    
 
 
-# In[60]:
+# In[61]:
 
 
 
@@ -683,7 +697,7 @@ if is_testing():
 
 # # Shell
 
-# In[61]:
+# In[62]:
 
 
 def shell(cmd):
@@ -698,7 +712,7 @@ def shell(cmd):
 
 # # GIT
 
-# In[62]:
+# In[63]:
 
 
 def gitGetHash():
@@ -708,7 +722,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[63]:
+# In[64]:
 
 
 def gitGetBranch():
@@ -718,7 +732,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[64]:
+# In[65]:
 
 
 def gitGetMessage():
@@ -728,7 +742,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[65]:
+# In[66]:
 
 
 def gitGetAllFiles():
@@ -738,7 +752,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[66]:
+# In[67]:
 
 
 def gitListByTime(path=None):
@@ -754,7 +768,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[67]:
+# In[68]:
 
 
 def shellSortDirsBySize():
@@ -772,14 +786,14 @@ if is_testing():
 
 
 
-# In[68]:
+# In[69]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[69]:
+# In[70]:
 
 
 def shell(cmd):
@@ -787,7 +801,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[70]:
+# In[71]:
 
 
 if is_testing():
@@ -819,7 +833,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[71]:
+# In[72]:
 
 
 if is_testing():
@@ -829,7 +843,7 @@ description-file = README.md
 """
 
 
-# In[72]:
+# In[73]:
 
 
 if is_testing():
@@ -852,28 +866,23 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[73]:
+# In[74]:
 
 
 if is_testing():
     package_files['README.md'] = ""
 
 
-# In[74]:
+# In[75]:
 
 
 if is_testing():
-    get_ipython().system(' jupyter nbconvert --to script lx.ipynb')
+    shell("jupyter nbconvert --to script lx.ipynb")
     package_files['lx/__init__.py'] = txtread("lx.py")
+    
 
 
-# In[ ]:
-
-
-
-
-
-# In[75]:
+# In[76]:
 
 
 if is_testing():
@@ -884,7 +893,7 @@ lx/__init__.py
 """
 
 
-# In[76]:
+# In[77]:
 
 
 if is_testing():
@@ -893,9 +902,13 @@ if is_testing():
             txtwrite(os.path.join(d, key), value)
 
         print("\n".join(fiFindByWildcard(os.path.join(d, '**/*'))))
-
-        #print(shell("cd {d} && git status && git config user.name 'lx' && git config user.email 'lx' && git commit -a -m 'Add' && git log && git push && python setup.py sdist && twine upload dist/* --verbose".format(d=d)))
-        print(shell("cd {d} && python3 setup.py sdist && twine upload dist/* --verbose".format(d=d)))
+        
+        output = shell("""python3 -c 'import importlib; lx = importlib.import_module(name=".", package="lx"); print(lx.version)'""")
+        print(output.strip(), 'Version correct: ', output.strip() == version)
+        
+        if output.strip() == version:
+            #print(shell("cd {d} && git status && git config user.name 'lx' && git config user.email 'lx' && git commit -a -m 'Add' && git log && git push && python setup.py sdist && twine upload dist/* --verbose".format(d=d)))
+            print(shell("cd {d} && python3 setup.py sdist && twine upload dist/* --verbose".format(d=d)))
 
 
 # In[ ]:
